@@ -1,6 +1,6 @@
 package Workflow::Factory;
 
-# $Id: Factory.pm 595 2013-07-02 06:54:58Z jonasbn $
+# $Id: Factory.pm 598 2013-07-03 09:52:32Z jonasbn $
 
 use warnings;
 use strict;
@@ -402,8 +402,7 @@ sub fetch_workflow {
     my $wf = $wf_class->new( $wf_id, $wf_info->{state}, $wf_config,
         $self->{_workflow_state}{$wf_type}, $self );
 
-    $wf->context( $context || Workflow::Context->new )
-        if ( not $wf->context() );
+    $wf->context( $wf_info->{context} || Workflow::Context->new ); #if ( not $wf->context() );
     $wf->last_update( $wf_info->{last_update} );
 
     $persister->fetch_extra_workflow_data($wf);
